@@ -15,7 +15,7 @@ def conv(val, unit, out):
         filename = '/temp'
     elif 9 <= unit <= 19:  # TYPE Time
         unit -= 9
-        out -= 1
+        out -= 9
         filename = '/time'
     elif 20 <= unit <= 55:  # TYPE Volume
         unit -= 20
@@ -127,20 +127,18 @@ def conv(val, unit, out):
         i = 1
         from currency_api.converter import CurrencyRates
         r = CurrencyRates()
-        factors = open(file_path+'currencyLetters.txt', 'r')
+        factors = open(file_path+'/currencyLetters.txt', 'r')
         conversionFactors = factors.readlines()
         factors.close()
-        factors = open(file_path+'currencyLetters.txt', 'r')
+        factors = open(file_path+'/currencyLetters.txt', 'r')
         reverseFactors = factors.readlines()
         factors.close()
         inRate = conversionFactors.pop(unit)
         inRate = inRate.strip('\n')
         outRate = reverseFactors.pop(out)
         outRate = outRate.strip('\n')
-        print(inRate, outRate)
         conversionFactor = ('a * ' + str(r.get_rate(inRate, 'USD')))
         reverseFactor = ('b * ' + str(r.get_rate('USD', outRate)))
-        print(conversionFactor, reverseFactor)
     if i == 0:
         if filename == 'error':
             returnSet = ['sorry, and error occurred']
@@ -149,14 +147,17 @@ def conv(val, unit, out):
             conversionFactors = factors.readlines()
             factors.close()
             conversionFactor = conversionFactors.pop(unit)
+            conversionFactors.insert(unit, conversionFactor)
             conversionFactor = conversionFactor.strip('\n')
             factors = open(file_path + (filename + 'Reverse.txt'), 'r')
             reverseFactors = factors.readlines()
             factors.close()
             reverseFactor = reverseFactors.pop(out)
+            reverseFactors.insert(out, reverseFactor)
             reverseFactor = reverseFactor.strip('\n')
     a = val
     b = eval(conversionFactor)
     c = eval(reverseFactor)
     returnSet.append(c)
     return returnSet
+# end
